"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDefaultGitHubReadme = exports.getLicenseText = exports.developTestSnippet = exports.installationSnippet = exports.v3BannerNotice = exports.generateReadme = void 0;
const outdent_1 = __importDefault(require("outdent"));
// @ts-expect-error missing types
const choosealicense_list_1 = __importDefault(require("@rexxars/choosealicense-list"));
function generateReadme(data) {
    const { user, pluginName, license, description } = data;
    return (0, outdent_1.default) `
    # ${pluginName}

    ${v3BannerNotice()}

    ${installationSnippet(pluginName !== null && pluginName !== void 0 ? pluginName : 'unknown')}

    ## Usage
    Add it as a plugin in sanity.config.ts (or .js):

    \`\`\`
     import {defineConfig} from 'sanity'
     import {myPlugin} from '${pluginName}'

     export const defineConfig({
         //...
         plugins: [
             myPlugin({})
         ]
     })
    \`\`\`
    ${getLicenseText(license === null || license === void 0 ? void 0 : license.id, (user === null || user === void 0 ? void 0 : user.name) ? user : undefined)}
    ${developTestSnippet()}
  `;
}
exports.generateReadme = generateReadme;
function v3BannerNotice() {
    return `> This is a **Sanity Studio v3** plugin.`;
}
exports.v3BannerNotice = v3BannerNotice;
function installationSnippet(packageName) {
    return (0, outdent_1.default) `
    ## Installation

    \`\`\`
    npm install --save ${packageName}@studio-v3
    \`\`\`
    `;
}
exports.installationSnippet = installationSnippet;
function developTestSnippet() {
    return (0, outdent_1.default) `
    ## Develop & test

    This plugin uses [@sanity/plugin-kit](https://github.com/sanity-io/plugin-kit)
    with default configuration for build & watch scripts.

    See [Testing a plugin in Sanity Studio](https://github.com/sanity-io/plugin-kit#testing-a-plugin-in-sanity-studio)
    on how to run this plugin with hotreload in the studio.
  `;
}
exports.developTestSnippet = developTestSnippet;
function getLicenseText(licenseId, user) {
    if (!licenseId) {
        return '';
    }
    let licenseName = choosealicense_list_1.default.find(licenseId).title;
    licenseName = licenseName === null || licenseName === void 0 ? void 0 : licenseName.replace(/\s+license$/i, '');
    let licenseText = '## License\n';
    if (licenseName && (user === null || user === void 0 ? void 0 : user.name)) {
        licenseText = `${licenseText}\n[${licenseName}](LICENSE) © ${user === null || user === void 0 ? void 0 : user.name}\n`;
    }
    else if (licenseName) {
        licenseText = `${licenseText}\n[${licenseName}](LICENSE)\n`;
    }
    else {
        licenseText = `${licenseText}\nSee [LICENSE](LICENSE)`;
    }
    return licenseText;
}
exports.getLicenseText = getLicenseText;
function isDefaultGitHubReadme(readme) {
    if (!readme) {
        return false;
    }
    const lines = readme.split('\n', 20).filter(Boolean);
    // title + _optional_ description
    return lines.length <= 2 && lines[0].startsWith('#');
}
exports.isDefaultGitHubReadme = isDefaultGitHubReadme;
//# sourceMappingURL=readme.js.map