"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = __importDefault(require("tap"));
const semver_workflow_1 = require("../src/presets/semver-workflow");
const outdent_1 = __importDefault(require("outdent"));
const readme_1 = require("../src/util/readme");
tap_1.default.test('readmeBaseUrl', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const testCases = [
        {
            pkg: { repository: { url: 'git+https://github.com/sanity-io/sanity.git' } },
            expectedUrl: 'https://github.com/sanity-io/sanity',
        },
        {
            pkg: { repository: { url: 'git+ssh://git@github.com/sanity-io/plugin-kit.git' } },
            expectedUrl: 'https://github.com/sanity-io/plugin-kit',
        },
        {
            pkg: { repository: { url: 'git@github.com:sanity-io/sanity-plugin-cloudinary.git' } },
            expectedUrl: 'https://github.com/sanity-io/sanity-plugin-cloudinary',
        },
        {
            pkg: { repository: { url: 'git+https://github.com/sanity-io/sanity-plugin.git' } },
            expectedUrl: 'https://github.com/sanity-io/sanity-plugin',
        },
        {
            pkg: { homepage: 'https://github.com/sanity-io/plugin-with-readme#readme' },
            expectedUrl: 'https://github.com/sanity-io/plugin-with-readme',
        },
    ];
    testCases.forEach(({ pkg, expectedUrl }) => t.equal((0, semver_workflow_1.readmeBaseurl)(pkg), expectedUrl));
}));
tap_1.default.test('missingSections', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const exactMatch = (0, outdent_1.default) `
  This a
  matches b
  exactly c
`;
    const exactMatch2 = (0, readme_1.getLicenseText)('MIT', { name: 'yolo' });
    const over50PercentMatch = (0, outdent_1.default) `
  This x
  matches y
  enough z
`;
    const fiftyPercentMatch = (0, outdent_1.default) `
  This
  does
  barely
  match
`;
    const lessThan50PercentMatch = (0, outdent_1.default) `
  This not
  does not
  not not
  match
`;
    const sections = [exactMatch, over50PercentMatch, fiftyPercentMatch, lessThan50PercentMatch];
    const readme = (0, outdent_1.default) `
    This a
    matches b
    exactly c

    This x
    matches y
    enough zzzzzz

    This
    does
    barely
    match

    This
    does
    miss

    ${exactMatch2}

  `;
    const missing = (0, semver_workflow_1.missingSections)(readme, sections);
    t.same(missing, [lessThan50PercentMatch]);
}));
//# sourceMappingURL=semver-workflow.test.js.map